==> blesta-5.10.2.zip: blesta/plugins/order/language/id_id/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.id_id
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'Email Pemulihan (Opsional)';
$lang['Signup.!error.email.blacklist'] = 'Pesanan Anda tidak dapat diproses saat ini.';
$lang['Signup.index.signup_btn'] = 'Buat akun';
$lang['Signup.index.continue_btn'] = 'Lanjutkan ke pembayaran';
$lang['Signup.index.login_btn'] = 'Masuk';
$lang['Signup.index.field_receive_email_marketing'] = 'Saya ingin menerima email tentang produk, layanan, dan penawaran baru.';
$lang['Signup.index.field_confirmpassword'] = 'Konfirmasi Kata Sandi';
$lang['Signup.index.field_newpassword'] = 'Kata sandi';
$lang['Signup.index.field_password'] = 'Kata sandi';
$lang['Signup.index.field_username'] = 'Nama pengguna';
$lang['Signup.index.field_action_signup'] = 'Membuat akun';
$lang['Signup.index.field_action_login'] = 'Masuk';
$lang['Signup.index.field_action_continue'] = 'Lanjutkan sebagai %1$s %2$s';
$lang['Signup.index.field_username_type_username'] = 'Menentukan nama pengguna';
$lang['Signup.index.field_username_type_email'] = 'Gunakan email sebagai nama pengguna';
$lang['Signup.index.field_email'] = 'Email';
$lang['Signup.index.field_fax'] = 'Faks';
$lang['Signup.index.field_phone'] = 'Telepon';
$lang['Signup.index.field_title'] = 'Judul';
$lang['Signup.index.field_country'] = 'Negara';
$lang['Signup.index.field_zip'] = 'Kode Pos/Kode Pos';
$lang['Signup.index.field_state'] = 'Negara Bagian/Provinsi';
$lang['Signup.index.field_city'] = 'Kota';
$lang['Signup.index.field_address2'] = 'Alamat 2';
$lang['Signup.index.field_address1'] = 'Alamat 1';
$lang['Signup.index.field_company'] = 'Perusahaan/Org.';
$lang['Signup.index.field_lastname'] = 'Nama belakang';
$lang['Signup.index.field_firstname'] = 'Nama depan';
$lang['Signup.index.field_taxid'] = 'Nomor Pokok Wajib Pajak / NPWP';
$lang['Signup.!notice.email_verification'] = 'Sebuah pesan telah dikirim untuk memverifikasi alamat email Anda. Silakan selesaikan verifikasi sesegera mungkin.';
$lang['Signup.!notice.force_email_usernames'] = 'Nama pengguna Anda akan sama dengan alamat email Anda.';
$lang['Signup.!error.not_client_owner'] = 'Anda harus masuk sebagai pemilik klien untuk melanjutkan.';
$lang['Signup.!error.captcha.invalid'] = 'Captcha yang dimasukkan tidak valid. Silakan coba lagi.';

==> blesta-5.11.4.zip: blesta/plugins/order/language/id_id/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.id_id
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'Email Pemulihan (Opsional)';
$lang['Signup.!error.email.blacklist'] = 'Pesanan Anda tidak dapat diproses saat ini.';
$lang['Signup.index.signup_btn'] = 'Buat akun';
$lang['Signup.index.continue_btn'] = 'Lanjutkan ke pembayaran';
$lang['Signup.index.login_btn'] = 'Masuk';
$lang['Signup.index.field_receive_email_marketing'] = 'Saya ingin menerima email tentang produk, layanan, dan penawaran baru.';
$lang['Signup.index.field_confirmpassword'] = 'Konfirmasi Kata Sandi';
$lang['Signup.index.field_newpassword'] = 'Kata sandi';
$lang['Signup.index.field_password'] = 'Kata sandi';
$lang['Signup.index.field_username'] = 'Nama pengguna';
$lang['Signup.index.field_action_signup'] = 'Membuat akun';
$lang['Signup.index.field_action_login'] = 'Masuk';
$lang['Signup.index.field_action_continue'] = 'Lanjutkan sebagai %1$s %2$s';
$lang['Signup.index.field_username_type_username'] = 'Menentukan nama pengguna';
$lang['Signup.index.field_username_type_email'] = 'Gunakan email sebagai nama pengguna';
$lang['Signup.index.field_email'] = 'Email';
$lang['Signup.index.field_fax'] = 'Faks';
$lang['Signup.index.field_phone'] = 'Telepon';
$lang['Signup.index.field_title'] = 'Judul';
$lang['Signup.index.field_country'] = 'Negara';
$lang['Signup.index.field_zip'] = 'Kode Pos/Kode Pos';
$lang['Signup.index.field_state'] = 'Negara Bagian/Provinsi';
$lang['Signup.index.field_city'] = 'Kota';
$lang['Signup.index.field_address2'] = 'Alamat 2';
$lang['Signup.index.field_address1'] = 'Alamat 1';
$lang['Signup.index.field_company'] = 'Perusahaan/Org.';
$lang['Signup.index.field_lastname'] = 'Nama belakang';
$lang['Signup.index.field_firstname'] = 'Nama depan';
$lang['Signup.index.field_taxid'] = 'Nomor Pokok Wajib Pajak / NPWP';
$lang['Signup.!notice.email_verification'] = 'Sebuah pesan telah dikirim untuk memverifikasi alamat email Anda. Silakan selesaikan verifikasi sesegera mungkin.';
$lang['Signup.!notice.force_email_usernames'] = 'Nama pengguna Anda akan sama dengan alamat email Anda.';
$lang['Signup.!error.not_client_owner'] = 'Anda harus masuk sebagai pemilik klien untuk melanjutkan.';
$lang['Signup.!error.captcha.invalid'] = 'Captcha yang dimasukkan tidak valid. Silakan coba lagi.';
$lang['Signup.otp.field_submit'] = 'Masuk';
$lang['Signup.otp.field_otp'] = 'Kata Sandi Sekali Pakai';
$lang['Signup.otp.login_heading'] = 'Masuk';
$lang['Signup.otp.description'] = 'Masukkan Kata Sandi Sekali Pakai Anda.';
$lang['Signup.otp.page_title'] = 'Masuk';
$lang['Signup.index.field_agree_tos'] = 'Saya telah membaca dan menyetujui <a href="%1$s" target="_blank">Syarat dan Ketentuan</a>';
$lang['Signup.!error.invalid_agree_tos'] = 'Anda harus menyatakan persetujuan Anda terhadap syarat dan ketentuan.';
